Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(961)

Unified Diff: chrome/utility/chrome_content_utility_client.cc

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/utility/chrome_content_utility_client.h ('k') | chromecast/browser/cast_content_browser_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/utility/chrome_content_utility_client.cc
diff --git a/chrome/utility/chrome_content_utility_client.cc b/chrome/utility/chrome_content_utility_client.cc
index a428baa4a353a41ba380c7c6919690d78967a04f..c4f49890569e020ec4f0f8cac114dc2d100c105b 100644
--- a/chrome/utility/chrome_content_utility_client.cc
+++ b/chrome/utility/chrome_content_utility_client.cc
@@ -190,11 +190,11 @@ bool ChromeContentUtilityClient::OnMessageReceived(
}
void ChromeContentUtilityClient::ExposeInterfacesToBrowser(
- shell::InterfaceRegistry* registry) {
+ service_manager::InterfaceRegistry* registry) {
// When the utility process is running with elevated privileges, we need to
// filter messages so that only a whitelist of IPCs can run. In Mojo, there's
// no way of filtering individual messages. Instead, we can avoid adding
// non-whitelisted Mojo services to the shell::InterfaceRegistry.
// TODO(amistry): Use a whitelist once the whistlisted IPCs have been
// converted to Mojo.
if (filter_messages_)
@@ -190,11 +190,11 @@ bool ChromeContentUtilityClient::OnMessageReceived(
// filter messages so that only a whitelist of IPCs can run. In Mojo, there's
// no way of filtering individual messages. Instead, we can avoid adding
- // non-whitelisted Mojo services to the shell::InterfaceRegistry.
+ // non-whitelisted Mojo services to the service_manager::InterfaceRegistry.
// TODO(amistry): Use a whitelist once the whistlisted IPCs have been
// converted to Mojo.
« no previous file with comments | « chrome/utility/chrome_content_utility_client.h ('k') | chromecast/browser/cast_content_browser_client.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698